@@ -530,7 +530,7 @@ def convert(
             for _ in range(3):
                 append_param = list(['--overwrite-input-shape'] + overwrite_input_shape) \
                     if overwrite_input_shape is not None else []
-                append_param = append_param + ['--no-large-tensor'] \
+                append_param = append_param + ['--no-large-tensor', '10MB'] \
                     if no_large_tensor else append_param
                 result = subprocess.check_output(
                     [
@@ -622,38 +622,40 @@ def convert(
     # Used to verify the output error of each OP in the TensorFlow model.
     full_ops_output_names = []
     onnx_tensor_infos_for_validation = None
-    for graph_node in graph.nodes:
-        full_ops_output_names_sub = []
-        for graph_node_output in graph_node.outputs:
-            full_ops_output_names_sub.append(graph_node_output.name)
-        full_ops_output_names.extend(full_ops_output_names_sub)
-    # Models with errors during inference in onnxruntime skip dummy inference.
-    try:
-        onnx_outputs_for_validation: List[np.ndarray] = dummy_onnx_inference(
-            onnx_graph=onnx_graph,
-            output_names=full_ops_output_names,
-        )
-        """
-        onnx_tensor_infos_for_validation:
-            {
-                onnx_output_name: np.ndarray,
-                onnx_output_name: np.ndarray,
-                onnx_output_name: np.ndarray,
-                            :
+    if check_onnx_tf_outputs_elementwise_close \
+        or check_onnx_tf_outputs_elementwise_close_full:
+        for graph_node in graph.nodes:
+            full_ops_output_names_sub = []
+            for graph_node_output in graph_node.outputs:
+                full_ops_output_names_sub.append(graph_node_output.name)
+            full_ops_output_names.extend(full_ops_output_names_sub)
+        # Models with errors during inference in onnxruntime skip dummy inference.
+        try:
+            onnx_outputs_for_validation: List[np.ndarray] = dummy_onnx_inference(
+                onnx_graph=onnx_graph,
+                output_names=full_ops_output_names,
+            )
+            """
+            onnx_tensor_infos_for_validation:
+                {
+                    onnx_output_name: np.ndarray,
+                    onnx_output_name: np.ndarray,
+                    onnx_output_name: np.ndarray,
+                                :
+                }
+            """
+            onnx_tensor_infos_for_validation = {
+                ops_output_name: onnx_output_for_validation \
+                    for ops_output_name, onnx_output_for_validation \
+                        in zip(full_ops_output_names, onnx_outputs_for_validation)
             }
-        """
-        onnx_tensor_infos_for_validation = {
-            ops_output_name: onnx_output_for_validation \
-                for ops_output_name, onnx_output_for_validation \
-                    in zip(full_ops_output_names, onnx_outputs_for_validation)
-        }
-    except Exception as ex:
-        print(
-            f'{Color.YELLOW}WARNING:{Color.RESET} ' +\
-            f'The optimization process for shape estimation is skipped ' +
-            f'because it contains OPs that cannot be inferred by the standard onnxruntime.'
-        )
-        print(f'{Color.YELLOW}WARNING:{Color.RESET} {ex}')
+        except Exception as ex:
+            print(
+                f'{Color.YELLOW}WARNING:{Color.RESET} ' +\
+                f'The optimization process for shape estimation is skipped ' +
+                f'because it contains OPs that cannot be inferred by the standard onnxruntime.'
+            )
+            print(f'{Color.YELLOW}WARNING:{Color.RESET} {ex}')
 
     if not non_verbose:
         print('')
